@@ -55,6 +55,8 @@ class CreateSessionRequest(AbstractModel):
         :type HostUserId: str
         :param Role: 【多人云游】角色；Player表示玩家；Viewer表示观察者
         :type Role: str
+        :param GameContext: 游戏相关参数
+        :type GameContext: str
         """
         self.ClientSession = None
         self.UserId = None
@@ -72,6 +74,7 @@ class CreateSessionRequest(AbstractModel):
         self.Optimization = None
         self.HostUserId = None
         self.Role = None
+        self.GameContext = None
 
 
     def _deserialize(self, params):
@@ -91,6 +94,7 @@ class CreateSessionRequest(AbstractModel):
         self.Optimization = params.get("Optimization")
         self.HostUserId = params.get("HostUserId")
         self.Role = params.get("Role")
+        self.GameContext = params.get("GameContext")
 
 
 class CreateSessionResponse(AbstractModel):
@@ -122,6 +126,44 @@ class CreateSessionResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class SaveGameArchiveRequest(AbstractModel):
+    """SaveGameArchive请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param UserId: 游戏用户ID
+        :type UserId: str
+        :param GameId: 游戏ID
+        :type GameId: str
+        """
+        self.UserId = None
+        self.GameId = None
+
+
+    def _deserialize(self, params):
+        self.UserId = params.get("UserId")
+        self.GameId = params.get("GameId")
+
+
+class SaveGameArchiveResponse(AbstractModel):
+    """SaveGameArchive返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class StopGameRequest(AbstractModel):
     """StopGame请求参数结构体
 
@@ -160,6 +202,52 @@ class StopGameResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class SwitchGameArchiveRequest(AbstractModel):
+    """SwitchGameArchive请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param UserId: 游戏用户ID
+        :type UserId: str
+        :param GameId: 游戏ID
+        :type GameId: str
+        :param GameArchiveUrl: 游戏存档Url
+        :type GameArchiveUrl: str
+        :param GameContext: 游戏相关参数
+        :type GameContext: str
+        """
+        self.UserId = None
+        self.GameId = None
+        self.GameArchiveUrl = None
+        self.GameContext = None
+
+
+    def _deserialize(self, params):
+        self.UserId = params.get("UserId")
+        self.GameId = params.get("GameId")
+        self.GameArchiveUrl = params.get("GameArchiveUrl")
+        self.GameContext = params.get("GameContext")
+
+
+class SwitchGameArchiveResponse(AbstractModel):
+    """SwitchGameArchive返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class TrylockWorkerRequest(AbstractModel):
     """TrylockWorker请求参数结构体
 
